@@ -1,17 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "0731d0b3d739c2846a441a55147cf53cd5301cf7",
-  "branchName": "release-client-5.15.1",
-  "buildTime": "2023-07-06 07:18:20 GMT",
-  "buildVersion": "5.1.473",
+  "commitId": "a168700eacc798f98a9f19e4d15253a8ca435940",
+  "branchName": "release-client-5.15.x",
+  "buildTime": "2023-07-24 02:24:03 GMT",
+  "buildVersion": "5.1.563",
   "css": [
-    "@zoom/client-calendar/static/css/default~app.7424f5e7.css",
-    "@zoom/client-calendar/static/css/vendors~app.dc891ce4.css"
+    "@zoom/client-calendar/static/css/chunk-vendors.dc891ce4.css",
+    "@zoom/client-calendar/static/css/app.93082b85.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/default~app.6af0a321.js",
-    "@zoom/client-calendar/static/js/vendors~app.b1310e99.js",
-    "@zoom/client-calendar/static/js/app.9f5f79d9.js"
+    "@zoom/client-calendar/static/js/chunk-vendors.17c1fa2e.js",
+    "@zoom/client-calendar/static/js/app.90ef6db8.js"
   ],
   "key": "@zoom/client-calendar"
 };
