@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "22b936a1d390f2be51c40130ef9b2787f7faed1a",
-  "branchName": "release-client-5.14.x",
-  "buildTime": "Sun, 28 May 2023 13:22:50 GMT",
-  "buildVersion": "261",
+  "commitId": "264b6ea61eb0cc5f148da820e40509cb89aea075",
+  "branchName": "release-client-5.15.x",
+  "buildTime": "Fri, 21 Jul 2023 09:14:22 GMT",
+  "buildVersion": "5.1.333",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
-    "@zoom/client-scheduler/static/css/index.39b774a5.css"
+    "@zoom/client-scheduler/static/css/index.f31cf0bd.css"
   ],
   "js": [
     "@zoom/client-scheduler/static/js/chunk-vendors.c685a8ed.js",
-    "@zoom/client-scheduler/static/js/index.23c56d52.js"
+    "@zoom/client-scheduler/static/js/index.7adefedc.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
